@@ -1,6 +1,6 @@
 use crate::enums::{TypeHolder, Types};
 use crate::types_structs::{Enum, ItemInfo, Struct, Trait, TYPE_CASE};
-use crate::{TypeCases, Language};
+use crate::{Language, TypeCases};
 use derive_new::new;
 use std::collections::{HashMap, VecDeque};
 use std::fs::{DirEntry, File};
@@ -9,6 +9,7 @@ use std::path::PathBuf;
 use std::rc::Rc;
 use syn::__private::ToTokens;
 use syn::{PathArguments, ReturnType, Type};
+use std::time::Instant;
 
 //constants
 
@@ -248,7 +249,8 @@ impl ItemsHolder {
             for _type in types {
                 //println!("type {}", _type);
                 if let Some(val) = map.get(_type) {
-                    if val.name() == item.name() { //Since classes with constructors have `self` as type
+                    if val.name() == item.name() {
+                        //Since classes with constructors have `self` as type
                         continue;
                     }
                     //println!("val {} item {}", val.name(), item.name());
@@ -291,11 +293,12 @@ impl ItemsHolder {
         self.enums_list.push(data)
     }
 
-    fn generate_interface(mut self,language:Language, out_file: &PathBuf) {
+    fn generate_interface(mut self, language: Language, out_file: &PathBuf) {
         //println!("final {:?}", self.final_list);
         let mut file = File::create(out_file).expect("Unable to write to disk");
-        file.write(b"//Automatically generated by rust_interface_generator\nuse crate::*;\n").unwrap();
-        if matches!(language,Language::Java) {
+        file.write(b"//Automatically generated by rust_interface_generator\nuse crate::*;\n")
+            .unwrap();
+        if matches!(language, Language::Java) {
             file.write_all(b"use jni_sys::*;\n").unwrap();
         }
         //first add enums since enums "can't" depend on other data structures
@@ -362,8 +365,8 @@ impl FileGenerator {
         }
     }
 
-    pub fn build(&self,language:Language) {
-        //let start = Instant::now();
+    pub fn build(&self, language: Language) {
+        let start = Instant::now();
         //the closure to be applied to each file
         let mut file_data: HashMap<Rc<String>, TypeHolder> = HashMap::new();
         let mut closure = |file: &DirEntry| {
@@ -495,8 +498,8 @@ impl FileGenerator {
                 TypeHolder::Enum(val) => holder.add_enum(val),
             }
         }
-        holder.generate_interface(language,&self.interface_file_path);
-        //println!("total time {:?}", start.elapsed());
+        holder.generate_interface(language, &self.interface_file_path);
+        eprintln!("Total Time Taken To Generate File {:?}", start.elapsed());
     }
 
     fn impl_data(map: &mut HashMap<Rc<String>, TypeHolder>, item: &syn::ItemImpl) {
